import type { PackageJson } from "./types.js";
interface Data {
    [key: string]: unknown;
}
interface Options {
    targetDir: string;
    pkg: PackageJson;
}
declare type GetSetPath = string | string[];
declare type ContentsUpdater = (fileContents: string) => (Promise<string> | string);
declare type JSONContentsUpdater<D = Data> = (fileData: D, setFn: (objPath: GetSetPath, value: unknown) => void) => (Promise<D | undefined> | D | undefined);
declare type Dep = "dependencies" | "devDependencies";
declare class Migration {
    private readonly _targetDir;
    private readonly _pkg;
    constructor(opts: Options);
    private _savePkg;
    get jsx(): boolean;
    get targetDir(): string;
    get pkg(): PackageJson;
    setPath(objPath: GetSetPath, value: unknown): Promise<void>;
    setScript(scriptName: string, value: string): Promise<void>;
    deletePath(objPath: GetSetPath): Promise<void>;
    deleteScript(scriptName: string): Promise<void>;
    upgradeScript(scriptName: string, oldValue: string, newValue: string): Promise<void>;
    addDependency(name: string, version: string): Promise<void>;
    addDevDependency(name: string, version: string): Promise<void>;
    upgradeDependency(name: string, version: string, defaultType?: Dep): Promise<void>;
    findDependency(name: string): "dependencies" | "devDependencies" | undefined;
    remove(dirName: string): Promise<void>;
    copy(sourceName: string, targetName?: string | null, overwrite?: boolean): Promise<void>;
    rename(source: string, target: string): Promise<void>;
    updateContents(file: string, updater: ContentsUpdater): Promise<void>;
    updateContentsJSON<D = Data>(file: string, updater: JSONContentsUpdater<D>): Promise<void>;
    updatePath(objPath: GetSetPath, updater: ContentsUpdater): Promise<void>;
    assertPath(objPath: GetSetPath, value: unknown, error: Error): void;
    assertNoPath(objPath: GetSetPath, error: Error): void;
    assertScript(scriptName: string, value: string, error: Error): void;
    assertNoScript(scriptName: string, error: Error): void;
    assertNoDependency(name: string, error: Error): void;
    assertNoDevDependency(name: string, error: Error): void;
    assertNoAnyDependency(name: string, error: Error): void;
    assertDevDependency(name: string, version: string | null, error: Error): void;
    removeDependency(name: string): Promise<void>;
    removeDevDependency(name: string): Promise<void>;
    removeAnyDependency(name: string): Promise<void>;
    yarn(): Promise<void>;
}
export { Migration };
export type { PackageJson };
//# sourceMappingURL=Migration.d.ts.map